@@ -111,12 +111,16 @@ public class AuthenticationEndpoint {
         validate(authenticationRequestBody);
         String hostname = RequestUtil.getHostHeader(request);
         String userAgent = RequestUtil.getUserAgent(request);
+        String forwardedFor = RequestUtil.getForwardedForWithRemoteIp(request);
+        String proto = RequestUtil.getForwardedProto(request);
         String trackingId = RequestUtil.getTrackingId(request);
         HostConfiguration configuration = ConfigurationHelper.getConfiguration(hostname);
         RequestUtil.checkUserAgent(userAgent, configuration);
         LoginCredentials credentials = getCredentials(request, authenticationRequestBody)
                 .withHost(hostname)
                 .withUserAgent(userAgent)
+                .withForwardedFor(forwardedFor)
+                .withForwardedProto(proto)
                 .withTrackingId(trackingId);
         try {
             AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
@@ -165,8 +169,8 @@ public class AuthenticationEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response logout(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Logging out client");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Logging out client");
         HostConfiguration configuration = sessionData.getConfiguration();
         AuthenticationService authenticationService = authenticationHandler.getAuthenticationService(configuration);
         LogoutRequestBody requestBody = Strings.isEmpty(rawRequestBody)
